#!/bin/sh

echo "################################################"
echo "Installing required packages"
echo "################################################"
apt-get --assume-yes install \
	build-essential \
	linux-headers-amd64 \
	iptables-persistent \
	vlc \
	firefox-esr \
	transmission \
	lightdm \
	i3 \
	redsocks \
	tor \
	rsync \
	unbound \
	vim-tiny

echo "################################################"
echo "Removing unused packages"
echo "################################################"
apt-get --assume-yes remove --purge nano


echo "################################################"
echo "Mounting VirtualBox VM guest additions CD..."
echo "################################################"
mount /dev/cdrom /mnt
echo "################################################"
echo "Compiling VM additions..."
echo "################################################"
/mnt/VBoxLinuxAdditions.run
echo "################################################"
echo "Unmounting CD..."
echo "################################################"
umount /mnt

echo "################################################"
echo "Copying static configs"
echo "################################################"
rsync -av static/ /

echo "################################################"
echo "Disabling IPv6"
echo "################################################"
echo net.ipv6.conf.all.disable_ipv6=1     >> /etc/sysctl.conf
echo net.ipv6.conf.default.disable_ipv6=1 >> /etc/sysctl.conf

echo "################################################"
echo "Force DNS servers in DHCP client"
echo "################################################"
echo "supersede domain-name-servers 127.0.0.1;" >> /etc/dhcp/dhclient.conf

for INSTUSER in `cd /home && ls -d *`
do
	echo "################################################"
	echo "Installing non-root setup for $INSTUSER"
	echo "################################################"
	cd user && rsync -av . /home/${INSTUSER}/; cd -
	chown -R ${INSTUSER}:${INSTUSER} /home/${INSTUSER}/
	echo "################################################"
	echo "Disable bash_history for user ${INSTUSER}"
	echo "################################################"
	rm -f /home/${INSTUSER}/.bash_history
	ln -s /dev/null /home/${INSTUSER}/.bash_history
done

echo "################################################"
echo "Disable bash_history for root"
echo "################################################"
rm -f /root/.bash_history
ln -s /dev/null /root/.bash_history

echo "################################################"
echo "Cleaning apt/pkg"
echo "################################################"
apt-get clean

echo "################################################"
echo "Cleaning syslog"
echo "################################################"
/etc/init.d/rsyslog stop
find /var/log -type f -print0 | xargs -0 rm

echo "################################################"
echo "Removing installer script, git package and dependencies"
echo "################################################"
#cd ..
#rm -rf torvm
#apt-get --assume-yes remove --purge git
#apt-get --assume-yes autoremove --purge

echo "################################################"
echo "Setup complete, please reboot to make it active"
echo "################################################"
